@@ -1,4 +1,4 @@
-from dataclasses import dataclass, field
+from attrs import define, field
 from typing import ClassVar, Dict, Union, List
 from resotolib.durations import parse_duration
 
@@ -27,7 +27,7 @@ default_config = {
 }
 
 
-@dataclass
+@define
 class TagValidatorConfig:
     kind: ClassVar[str] = "plugin_tagvalidator"
     enabled: bool = field(
@@ -39,7 +39,7 @@ class TagValidatorConfig:
         metadata={"description": "Dry run"},
     )
     config: Dict[str, Union[Dict, List]] = field(
-        default_factory=lambda: default_config,
+        factory=lambda: default_config,
         metadata={
             "description": (
                 "Configuration for the plugin\n"
